.. _utils.geometry:

Geometry Helpers
================

.. automodule:: eyetrace.utils.geometry
   :members:
   :undoc-members:
   :show-inheritance:

Geometric calculations such as distance between points, vector
normalization, angle between vectors, and point projection onto a line.